@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Annotation.pm,v 1.19 2005/06/14 12:55:59 fredo Exp $
+#   $Id: Annotation.pm,v 2.0 2005/11/16 02:16:00 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Annotation;
@@ -44,7 +44,7 @@ BEGIN
 
     @ISA = qw(PDF::API2::Basic::PDF::Dict);
 
-    ( $VERSION ) = '$Revision: 1.19 $' =~ /Revision: (\S+)\s/; # $Date: 2005/06/14 12:55:59 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.0 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/11/16 02:16:00 $
 
     use utf8;
     use Encode qw(:all);
@@ -214,6 +214,29 @@ sub text
     return($self);
 }
 
+=item $ant->movie $file, $contentype, %opts
+
+Defines the annotation as a movie from $file with $contentype and
+options %opts (-rect).
+
+=cut
+
+sub movie
+{
+    my ($self,$file,$contentype,%opts)=@_;
+    $self->{Subtype}=PDFName('Movie');
+    $self->{A}=PDFBool(1);
+    $self->{Movie}=PDFDict();
+    $self->{Movie}->{F}=PDFDict();
+    $self->{' apipdf'}->new_obj($self->{Movie}->{F});
+    my $f=$self->{Movie}->{F};
+    $f->{Type}=PDFName('EmbeddedFile');
+    $f->{Subtype}=PDFName($contentype);
+    $f->{' streamfile'}=$file;
+    $self->rect(@{$opts{-rect}}) if(defined $opts{-rect});
+    return($self);
+}
+
 =item $ant->rect $llx, $lly, $urx, $ury
 
 Sets the rectangle of the annotation.
@@ -408,6 +431,21 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Annotation.pm,v $
+    Revision 2.0  2005/11/16 02:16:00  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:48  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:24  areibens
+    genesis
+
+    Revision 1.21  2005/06/17 19:43:46  fredo
+    fixed CPAN modulefile versioning (again)
+
+    Revision 1.20  2005/06/17 18:53:04  fredo
+    fixed CPAN modulefile versioning (dislikes cvs)
+
     Revision 1.19  2005/06/14 12:55:59  fredo
     fixed typo for text annotation leaving it empty
 
